@@ -1264,8 +1264,10 @@ class bfit(object):
         title_dict = {'c':"combined", 
                       'p':"positive_helicity", 
                       'n':"negative_helicity", 
-                      'fwd':'forward_counter', 
-                      'bck':'backward_counter', 
+                      'f':'forward_counter', 
+                      'b':'backward_counter', 
+                      'r':'right_counter', 
+                      'l':'left_counter', 
                       'time_s':'time_s', 
                       'freq':"freq_Hz", 
                       'mV':'voltage_mV', 
